<!DOCTYPE html>
<html lang="en">
<head>
    <meta charset="UTF-8">
    <title>欢迎访问 AKTools 主页</title>
</head>
<body>
<h1 style="text-align: center; color: coral">欢迎来到 AKTools 的主页</h1>

<div>
    <p style="text-align: center; color: black">
        您当前服务器的 IP 地址及端口为：{{ip_address}}
    </p>
    <p style="text-align: center; color: black">
        当前的 AKTools 版本为：{{at_current_version}}，AKShare 版本为：{{ak_current_version}}
    </p>
    <p style="text-align: center; color: blue">
        最新的 AKTools 版本为：{{at_latest_version}}，AKShare 版本为：{{ak_latest_version}}
    </p>
    <p style="text-align: center; color: black">
        请通过：http://{{ip_address}}/api/public/{请求的数据接口} 来访问相关的数据接口
    </p>
    <p style="text-align: center; color: black">
        接口测试在线文档请访问：<a href="http://{{ip_address}}/docs">http://{{ip_address}}/docs</a>
    </p>
    <p style="text-align: center; color: black">
        测试链接请访问：<a href="http://{{ip_address}}/api/public/stock_zh_a_hist">http://{{ip_address}}/api/public/stock_zh_a_hist</a>
    </p>

</div>

<div style="text-align: center">
    <ul style="; list-style:none;">
        <li><a href="https://github.com/akfamily/aktools">AKTools 项目地址</a></li>
        <li><a href="https://aktools.akfamily.xyz">AKTools 官方文档</a></li>
        <li><a href="https://github.com/akfamily/akshare">AKShare 项目地址</a></li>
        <li><a href="https://akshare.akfamily.xyz">AKShare 官方文档</a></li>
    </ul>
</div>

</body>
</html>